@@ -1,7 +1,7 @@
 # as explained in "preamble" section in documentation
 import dash
-import dash_html_components as html
-import dash_core_components as dcc
+from dash import html
+from dash import dcc
 import crystal_toolkit.components as ctc
 
 app = dash.Dash()
