@@ -1,7 +1,7 @@
 # standard Dash imports
 import dash
-import dash_html_components as html
-import dash_core_components as dcc
+from dash import html
+from dash import dcc
 
 # standard Crystal Toolkit import
 import crystal_toolkit.components as ctc
