@@ -1,7 +1,7 @@
 # standard Dash imports
 import dash
-import dash_core_components as dcc
-import dash_html_components as html
+from dash import dcc
+from dash import html
 from dash.dependencies import Input, Output, State
 from dash.exceptions import PreventUpdate
 from dash_mp_components import JsonView
