@@ -12,7 +12,7 @@ from crystal_toolkit.components.robocrys import RobocrysComponent
 
 from crystal_toolkit.components.diffraction import (
     XRayDiffractionComponent,
-    DiffractionPanelComponent,
+    TEMDiffractionComponent,
 )
 
 # from crystal_toolkit.components.xas import XASComponent, XASPanelComponent
@@ -30,10 +30,7 @@ from crystal_toolkit.components.bandstructure import (
 #     PhaseDiagramComponent,
 #     PhaseDiagramPanelComponent,
 # )
-# from crystal_toolkit.components.pourbaix import (
-#     PourbaixDiagramComponent,
-#     PourbaixDiagramPanelComponent,
-# )
+from crystal_toolkit.components.pourbaix import PourbaixDiagramComponent
 from crystal_toolkit.components.localenv import LocalEnvironmentPanel
 
 from crystal_toolkit.components.transformations.core import AllTransformationsComponent
