@@ -1,6 +1,6 @@
-import dash_core_components as dcc
-import dash_html_components as html
-import dash_table as dt
+from dash import dcc
+from dash import html
+from dash import dash_table as dt
 
 from dash.dependencies import Input, Output, State
 
