@@ -2,8 +2,8 @@ from base64 import b64decode
 from tempfile import NamedTemporaryFile
 
 import dash
-import dash_core_components as dcc
-import dash_html_components as html
+from dash import dcc
+from dash import html
 from dash.dependencies import Input, Output, State
 from dash.exceptions import PreventUpdate
 from monty.serialization import loadfn
