@@ -402,7 +402,6 @@ Sub-layouts:  \n{layouts}"""
         """
         return html.Div(list(self._sub_layouts.values()))
 
-    @abstractmethod
     def generate_callbacks(self, app, cache):
         """
         Generate all callbacks associated with the layouts in this app. Assume
@@ -410,11 +409,12 @@ Sub-layouts:  \n{layouts}"""
         guaranteed that all layouts will be displayed to the end user at all
         times, but it's important the callbacks are defined on the server.
         """
-        raise NotImplementedError
+        return None
 
     def get_numerical_input(
         self,
         kwarg_label: str,
+        default: Optional[Union[int, float, List]] = None,
         state: Optional[dict] = None,
         label: Optional[str] = None,
         help_str: str = None,
@@ -429,16 +429,32 @@ Sub-layouts:  \n{layouts}"""
         :param kwarg_label: The name of the corresponding Python input, this is used
         to name the component.
         :param label: A description for this input.
-        :param state: Used to set state for this input, dict with arg name or kwarg name as key
+        :param default: A default value for this input.
+        :param state: Used to set default state for this input, use a dict with the kwarg_label as a key
+        and the default value as a value. Ignored if `default` is set. It can be useful to use
+        `state` if you want to set defaults for multiple inputs from a single dictionary.
         :param help_str: Text for a tooltip when hovering over label.
         :param is_int: if True, will use a numeric input
         :param shape: (3, 3) for matrix, (1, 3) for vector, (1, 1) for scalar
         :return: a Dash layout
         """
 
-        default = np.full(shape, state.get(kwarg_label))
+        state = state or {}
+        default = np.full(shape, default or state.get(kwarg_label))
         default = np.reshape(default, shape)
 
+        style = {
+            "textAlign": "center",
+            # shorter default width if matrix or vector
+            "width": "5rem",
+            "marginRight": "0.2rem",
+            "marginBottom": "0.2rem",
+            "height": "36px",
+        }
+        if "style" in kwargs:
+            style.update(kwargs["style"])
+            del kwargs["style"]
+
         def matrix_element(idx, value=0):
             # TODO: maybe move element out of the name
             mid = self.id(kwarg_label, is_kwarg=True, idx=idx, hint=shape)
@@ -450,14 +466,7 @@ Sub-layouts:  \n{layouts}"""
                     inputMode="numeric",
                     debounce=True,
                     className="input",
-                    style={
-                        "textAlign": "center",
-                        # shorter default width if matrix or vector
-                        "width": "5rem",
-                        "marginRight": "0.2rem",
-                        "marginBottom": "0.2rem",
-                        "height": "36px",
-                    },
+                    style=style,
                     value=float(value) if value is not None else None,
                     persistence=True,
                     type="number",
@@ -469,14 +478,7 @@ Sub-layouts:  \n{layouts}"""
                     inputMode="numeric",
                     debounce=True,
                     className="input",
-                    style={
-                        "textAlign": "center",
-                        # shorter default width if matrix or vector
-                        "width": "5rem",
-                        "marginRight": "0.2rem",
-                        "marginBottom": "0.2rem",
-                        "height": "36px",
-                    },
+                    style=style,
                     value=int(value) if value is not None else None,
                     persistence=True,
                     type="number",
@@ -513,30 +515,33 @@ Sub-layouts:  \n{layouts}"""
     def get_slider_input(
         self,
         kwarg_label: str,
-        state: Optional[dict] = None,
+        default: Optional = None,
+        state: Dict = None,
         label: Optional[str] = None,
         help_str: str = None,
         multiple: bool = False,
         **kwargs,
     ):
 
-        default = state.get(kwarg_label) or False
+        state = state or {}
+        default = default or state.get(kwarg_label)
+
+        slider_kwargs = dict(
+            tooltip={"placement": "bottom", "always_visible": True}, persistence=False,
+        )
+        slider_kwargs.update(kwargs)
 
         if multiple:
             slider_input = dcc.RangeSlider(
                 id=self.id(kwarg_label, is_kwarg=True, hint="slider"),
-                tooltip={"placement": "bottom"},
                 value=default,
-                persistence=True,
-                **kwargs,
+                **slider_kwargs,
             )
         else:
             slider_input = dcc.Slider(
                 id=self.id(kwarg_label, is_kwarg=True, hint="slider"),
-                tooltip={"placement": "bottom"},
                 value=default,
-                persistence=True,
-                **kwargs,
+                **slider_kwargs,
             )
 
         return add_label_help(slider_input, label, help_str)
@@ -544,6 +549,7 @@ Sub-layouts:  \n{layouts}"""
     def get_bool_input(
         self,
         kwarg_label: str,
+        default: Optional[bool] = None,
         state: Optional[dict] = None,
         label: Optional[str] = None,
         help_str: str = None,
@@ -555,19 +561,23 @@ Sub-layouts:  \n{layouts}"""
         :param kwarg_label: The name of the corresponding Python input, this is used
         to name the component.
         :param label: A description for this input.
-        :param state: Used to set state for this input, dict with arg name or kwarg name as key
+        :param default: A default value for this input.
+        :param state: Used to set default state for this input, use a dict with the kwarg_label as a key
+        and the default value as a value. Ignored if `default` is set. It can be useful to use
+        `state` if you want to set defaults for multiple inputs from a single dictionary.
         :param help_str: Text for a tooltip when hovering over label.
         :return: a Dash layout
         """
 
-        default = state.get(kwarg_label) or False
+        state = state or {}
+        default = default or state.get(kwarg_label) or False
 
         bool_input = dcc.Checklist(
             id=self.id(kwarg_label, is_kwarg=True, hint="bool"),
             style={"width": "5rem"},
             options=[{"label": "", "value": "enabled"}],
             value=["enabled"] if default else [],
-            persistence=True,
+            persistence=False,
         )
 
         return add_label_help(bool_input, label, help_str)
@@ -575,6 +585,7 @@ Sub-layouts:  \n{layouts}"""
     def get_choice_input(
         self,
         kwarg_label: str,
+        default: Optional[str] = None,
         state: Optional[dict] = None,
         label: Optional[str] = None,
         help_str: str = None,
@@ -588,19 +599,23 @@ Sub-layouts:  \n{layouts}"""
         :param kwarg_label: The name of the corresponding Python input, this is used
         to name the component.
         :param label: A description for this input.
-        :param state: Used to set state for this input, dict with arg name or kwarg name as key
+        :param default: A default value for this input.
+        :param state: Used to set default state for this input, use a dict with the kwarg_label as a key
+        and the default value as a value. Ignored if `default` is set. It can be useful to use
+        `state` if you want to set defaults for multiple inputs from a single dictionary.
         :param help_str: Text for a tooltip when hovering over label.
         :param options: Options to choose from, as per dcc.Dropdown
         :return: a Dash layout
         """
 
-        default = state.get(kwarg_label)
+        state = state or {}
+        default = default or state.get(kwarg_label)
 
         option_input = dcc.Dropdown(
             id=self.id(kwarg_label, is_kwarg=True, hint="literal"),
             options=options if options else [],
             value=default,
-            persistence=True,
+            persistence=False,
             clearable=False,
             **kwargs,
         )
@@ -610,14 +625,27 @@ Sub-layouts:  \n{layouts}"""
     def get_dict_input(
         self,
         kwarg_label: str,
+        default: Optional = None,
         state: Optional[dict] = None,
         label: Optional[str] = None,
         help_str: str = None,
         key_name: str = "key",
         value_name: str = "value",
     ):
+        """
 
-        default = state.get(kwarg_label) or {}
+        :param kwarg_label:
+        :param default:
+        :param state:
+        :param label:
+        :param help_str:
+        :param key_name:
+        :param value_name:
+        :return:
+        """
+
+        state = state or {}
+        default = default or state.get(kwarg_label) or {}
 
         dict_input = dt.DataTable(
             id=self.id(kwarg_label, is_kwarg=True, hint="dict"),
@@ -627,7 +655,7 @@ Sub-layouts:  \n{layouts}"""
             ],
             data=[{"key": k, "value": v} for k, v in default.items()],
             editable=True,
-            persistence=True,
+            persistence=False,
         )
 
         return add_label_help(dict_input, label, help_str)
@@ -653,10 +681,23 @@ Sub-layouts:  \n{layouts}"""
         return {"component_id": self._id, "kwarg_label": ALL, "idx": ALL, "hint": ALL}
 
     def reconstruct_kwarg_from_state(self, state, kwarg_name):
-        return self.reconstruct_kwargs_from_state(state)[kwarg_name]
+        return self.reconstruct_kwargs_from_state(
+            state=state, kwarg_labels=[kwarg_name]
+        )[kwarg_name]
 
-    def reconstruct_kwargs_from_state(self, state) -> Dict:
-        # TODO: change to take callback_context directly
+    def reconstruct_kwargs_from_state(self, state=None, kwarg_labels=None) -> Dict:
+        """
+        Generate
+
+        :param state: optional, a Dash callback context input or state
+        :param kwarg_labels: optional, parse only a specific kwarg or list of kwargs
+        :return: A dictionary of keyword arguments with their values
+        """
+
+        if not state:
+            state = {}
+            state.update(dash.callback_context.inputs)
+            state.update(dash.callback_context.states)
 
         kwargs = {}
         for k, v in state.items():
@@ -672,6 +713,9 @@ Sub-layouts:  \n{layouts}"""
 
             kwarg_label = d["kwarg_label"]
 
+            if kwarg_labels and kwarg_label not in kwarg_labels:
+                continue
+
             try:
                 k_type = literal_eval(d["hint"])
             except ValueError:
@@ -679,8 +723,6 @@ Sub-layouts:  \n{layouts}"""
 
             idx = literal_eval(d["idx"])
 
-            # TODO: catch Exceptions here, and display validation error to user if incorrect kwargs supplied
-
             try:
 
                 if isinstance(k_type, tuple):
@@ -689,6 +731,7 @@ Sub-layouts:  \n{layouts}"""
                         kwargs[kwarg_label] = np.empty(k_type)
                     v = literal_eval(str(v))
                     if (v is not None) and (kwargs[kwarg_label] is not None):
+                        # print("debugging", kwargs, kwarg_label, idx, v)
                         if isinstance(v, list):
                             print(
                                 "This shouldn't happen! Debug required.",
@@ -722,7 +765,7 @@ Sub-layouts:  \n{layouts}"""
 
             except Exception as exc:
                 # Not raised intentionally but if you notice this in logs please investigate.
-                print("This is a problem, debug required.", exc)
+                print("This is a problem, debug required.", exc, d, v, type(v))
 
         for k, v in kwargs.items():
             if isinstance(v, np.ndarray):
