@@ -2,12 +2,21 @@ import numpy as np
 from pymatgen.core.periodic_table import DummySpecie
 from scipy.spatial.qhull import Delaunay
 
-from crystal_toolkit.core.scene import Scene, Cubes, Spheres, Cylinders, Surface, Convex
+from crystal_toolkit.core.scene import (
+    Scene,
+    Cubes,
+    Spheres,
+    Cylinders,
+    Surface,
+    Convex,
+    Arrows,
+)
 from crystal_toolkit.core.legend import Legend
 
 from itertools import chain
 from pymatgen.core.sites import Site
 from pymatgen.analysis.graphs import ConnectedSite
+from pymatgen.electronic_structure.core import Magmom
 
 from typing import List, Optional
 
@@ -26,6 +35,8 @@ def get_site_scene(
     draw_polyhedra: bool = True,
     explicitly_calculate_polyhedra_hull: bool = False,
     bond_radius: float = 0.1,
+    draw_magmoms: bool = True,
+    magmom_scale: float = 1.0,
     legend: Optional[Legend] = None,
 ) -> Scene:
     """
@@ -48,6 +59,7 @@ def get_site_scene(
     atoms = []
     bonds = []
     polyhedron = []
+    magmoms = []
 
     legend = legend or Legend(self)
 
@@ -58,6 +70,9 @@ def get_site_scene(
 
     position = self.coords.tolist()
 
+    radii = [legend.get_radius(sp, site=self) for sp in self.species.keys()]
+    max_radius = float(min(radii))
+
     for idx, (sp, occu) in enumerate(self.species.items()):
 
         if isinstance(sp, DummySpecie):
@@ -88,6 +103,10 @@ def get_site_scene(
                 name += " ({}% occupancy)".format(occu)
             name += f" ({position[0]:.3f}, {position[1]:.3f}, {position[2]:.3f})"
 
+            if self.properties:
+                for k, v in self.properties.items():
+                    name += f" ({k} = {v})"
+
             sphere = Spheres(
                 positions=[position],
                 color=color,
@@ -99,6 +118,25 @@ def get_site_scene(
             )
             atoms.append(sphere)
 
+        # Add magmoms
+        if draw_magmoms:
+            if magmom := self.properties.get("magmom"):
+                # enforce type
+                magmom = np.array(Magmom(magmom).get_moment())
+                magmom = 2 * magmom_scale * max_radius * magmom
+                tail = np.array(position) - 0.5 * np.array(magmom)
+                head = np.array(position) + 0.5 * np.array(magmom)
+
+                arrow = Arrows(
+                    positionPairs=[[tail, head]],
+                    color="red",
+                    radius=0.20,
+                    headLength=0.5,
+                    headWidth=0.4,
+                    clickable=True,
+                )
+                magmoms.append(arrow)
+
     if not is_ordered and not np.isclose(phiEnd, np.pi * 2):
         # if site occupancy doesn't sum to 100%, cap sphere
         sphere = Spheres(
@@ -205,6 +243,7 @@ def get_site_scene(
             Scene("atoms", contents=atoms),
             Scene("bonds", contents=bonds),
             Scene("polyhedra", contents=polyhedron),
+            Scene("magmoms", contents=magmoms),
         ],
         origin=origin,
     )
